@@ -6,10 +6,11 @@ use utf8;
 use warnings;
 
 # Version.
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 # Modules.
 use Acme::CPANAuthors::Register(
+	'CHOROBA' => 'E. Choroba',
 	'DANPEDER' => 'Daniel Peder',
 	'HIHIK' => 'Jiří Václavík',
 	'HPA' => 'Petr Vraník',
@@ -100,26 +101,27 @@ See documentation for L<Acme::CPANAuthors> for more details.
 
  # Output:
  # [
- #     [0]  "DANPEDER",
- #     [1]  "HIHIK",
- #     [2]  "HPA",
- #     [3]  "JANPAZ",
- #     [4]  "JANPOM",
- #     [5]  "JENDA",
- #     [6]  "JSPICAK",
- #     [7]  "KLE",
- #     [8]  "MAJLIS",
- #     [9]  "MILSO",
- #     [10] "MJFO",
- #     [11] "PAJAS",
- #     [12] "PASKY",
- #     [13] "PEK",
- #     [14] "RUS",
- #     [15] "RVASICEK",
- #     [16] "SKIM",
- #     [17] "TKR",
- #     [18] "TRIPIE",
- #     [19] "ZOUL"
+ #     [0]  "CHOROBA",
+ #     [1]  "DANPEDER",
+ #     [2]  "HIHIK",
+ #     [3]  "HPA",
+ #     [4]  "JANPAZ",
+ #     [5]  "JANPOM",
+ #     [6]  "JENDA",
+ #     [7]  "JSPICAK",
+ #     [8]  "KLE",
+ #     [9]  "MAJLIS",
+ #     [10] "MILSO",
+ #     [11] "MJFO",
+ #     [12] "PAJAS",
+ #     [13] "PASKY",
+ #     [14] "PEK",
+ #     [15] "RUS",
+ #     [16] "RVASICEK",
+ #     [17] "SKIM",
+ #     [18] "TKR",
+ #     [19] "TRIPIE",
+ #     [20] "ZOUL"
  # ]
 
 =head1 DEPENDENCIES
@@ -142,6 +144,6 @@ BSD license.
 
 =head1 VERSION
 
-0.09
+0.10
 
 =cut
